@@ -186,7 +186,9 @@ camera_init (void)
 	   euler_to_quaternion (0.0, 0.0, RAD (-90.0), camera->q);
 	 */
 	euler_to_quaternion (RAD (135.0), RAD (35.0), RAD (-90.0), camera->q);
-	g_print ("camera_init:%.2f %.2f %.2f %.2f\n", camera->q[0], camera->q[1], camera->q[2], camera->q[3]);
+	/*
+	   g_print ("camera_init:%.2f %.2f %.2f %.2f\n", camera->q[0], camera->q[1], camera->q[2], camera->q[3]);
+	 */
 	camera->tilt = 0.0;			/* 真下 */
 	camera->dist = 20000000.0;
 
@@ -220,7 +222,7 @@ camera_set_position (gdouble lon, gdouble lat)
 
 /* tilt と heading をゼロにする */
 void
-camera_reset(void)
+camera_reset (void)
 {
 	euler_to_quaternion (RAD (camera->lon_target), RAD (camera->lat_target), RAD (-90.0), camera->q_target);
 	camera->tilt_target = 0.0;
@@ -231,7 +233,7 @@ camera_reset(void)
 		camera->q[2] = camera->q_target[2];
 		camera->q[3] = camera->q_target[3];
 
-        camera->tilt = 0.0;
+		camera->tilt = 0.0;
 	}
 
 	calc_camera ();
@@ -884,24 +886,32 @@ camera_check_overlap (gdouble north, gdouble south, gdouble west, gdouble east)
 	gdouble ceast;
 	gdouble cnorth;
 
+	/*
+	   g_print("camera_check_overlap:n:%.2f s:%.2f w:%.2f e:%.2f\n", north, south, west, east);
+	 */
+
 	cwest = camera->lon - camera->deg_view_lon / 2.0;
 	ceast = camera->lon + camera->deg_view_lon / 2.0;
 	cnorth = camera->lat + camera->deg_view_lat / 2.0;
 	csouth = camera->lat - camera->deg_view_lat / 2.0;
 
-	if (west < -180.0) {
+	if (cwest < -180.0) {
 		cwest += 360.0;
 	}
-	if (east > 180.0) {
+	if (ceast > 180.0) {
 		ceast -= 360.0;
 	}
-	if (north > 90.0) {
+	if (cnorth > 90.0) {
 		cnorth = 90.0;
 	}
-	if (south < -90.0) {
+	if (csouth < -90.0) {
 		csouth = -90.0;
 	}
 
+	/*
+	   g_print("camera_check_overlap:camera:n:%.2f s:%.2f w:%.2f e:%.2f\n", cnorth, csouth, cwest, ceast);
+	 */
+
 	return util_check_overlap (cwest, csouth, ceast, cnorth, west, south, east, north);
 }
 
