@@ -50,9 +50,6 @@
 /********************************************/
 
 static GtkWidget *hbox_all;
-static GtkWidget *draw_dummy;
-static GdkGLContext *glcontext_dummy;
-static GdkGLDrawable *gldrawable_dummy;
 static GdkGLContext *glcontext_main;
 static GdkGLDrawable *gldrawable_main;
 
@@ -162,7 +159,7 @@ glarea_get_size (gint * w, gint * h)
 
 #include <errno.h>
 
-static gboolean
+gboolean
 glarea_gl_begin (void)
 {
 	gdk_threads_enter ();
@@ -182,7 +179,7 @@ glarea_gl_begin (void)
 	}
 }
 
-static void
+void
 glarea_gl_end (void)
 {
 	gdk_gl_drawable_gl_end (gldrawable_main);
@@ -195,69 +192,6 @@ glarea_gl_end (void)
 	 */
 }
 
-gboolean
-glarea_dummy_gl_begin (void)
-{
-	gdk_threads_enter ();
-
-	/*
-	   g_print ("glarea_dummy_gl_begin:drawable:%p context:%p\n", gldrawable_dummy, glcontext_dummy);
-	 */
-
-	if (gdk_gl_drawable_gl_begin (gldrawable_dummy, glcontext_dummy) == FALSE) {
-		g_print ("####################################################################dummy_gl_begin:false\n");
-		gl_error ();
-		return FALSE;
-	} else {
-		return TRUE;
-	}
-}
-
-void
-glarea_dummy_gl_end (void)
-{
-	gdk_gl_drawable_gl_end (gldrawable_dummy);
-	gdk_flush ();
-
-	gdk_threads_leave ();
-
-	/*
-	   g_print ("glarea_dummy_gl_end\n");
-	 */
-}
-
-/******************************************/
-
-static gboolean
-idle_func_texture_free (gpointer data)
-{
-	guint *t_num = (guint *) data;
-
-	/*
-	   g_print ("idle_func_texture_free\n");
-	 */
-
-	glarea_gl_begin ();
-	glDeleteTextures (1, t_num);
-	glarea_gl_end ();
-
-	g_free (t_num);
-
-	return FALSE;				/* FALSE を返すと単発で終了 */
-}
-
-/* テクスチャーの開放を色々なスレッドでしようとすると面倒なので、idle ループ内でする。  */
-void
-glarea_util_texture_free (guint n)
-{
-	guint *t_num;
-
-	t_num = g_new (guint, 1);
-	*t_num = n;
-
-	g_idle_add (idle_func_texture_free, t_num);
-}
-
 /******************************************/
 
 static gboolean update_process_start = FALSE;
@@ -324,24 +258,25 @@ frame_counter (gdouble sec_render, gdouble sec_all)
 }
 
 void
-create_info(void)
+create_info (void)
 {
-    gint n;
+	gint n;
 
-    n = mmapthread_get_n_download();
+	n = mmapthread_get_n_download ();
 
-    if(n == 0){
-	    text_status[0] = '\0';
-    } else if(n == 1){
-	    sprintf (text_status, "Downloading ....  ( %d file )", n);
-    } else if(n > 1){
-	    sprintf (text_status, "Downloading ....  ( %d files )", n);
-    } else {
-        /* ありえん */
-	    text_status[0] = '\0';
-    }
+	if (n == 0) {
+		text_status[0] = '\0';
+	} else if (n == 1) {
+		sprintf (text_status, "Downloading ....  ( %d file )", n);
+	} else if (n > 1) {
+		sprintf (text_status, "Downloading ....  ( %d files )", n);
+	} else {
+		/* ありえん */
+		text_status[0] = '\0';
+	}
 
-	sprintf (text_info, "fps : %6.2f   render : %6.2f (msec)       %s", info_fps, info_render_time * 1000.0, text_status);
+	sprintf (text_info, "fps : %6.2f   render : %6.2f (msec)       %s", info_fps, info_render_time * 1000.0,
+			 text_status);
 }
 
 /*
@@ -458,7 +393,7 @@ set_projection_matrix (void)
 	alt = camera_get_alt ();
 
 	fovy = 360.0 / G_PI * atan ((area->h / 2.0) / l);
-	near = alt * 0.5;
+	near = alt * 0.2;
 	far = (radius + alt) * 2.0;
 	/*
 	   far = sqrt ((radius + alt) * (radius + alt) - radius * radius);
@@ -560,7 +495,7 @@ render_single (void)
 	gdouble sec_all;
 
 	idle_render = camera_next_step ();
-    create_info();
+	create_info ();
 
 	g_get_current_time (&start);
 	render ();
@@ -763,7 +698,9 @@ glarea_configure_event_cb (GtkWidget * glarea, GdkEventConfigure * event, gpoint
 	area->w = glarea->allocation.width;
 	area->h = glarea->allocation.height;
 
-	g_print ("glarea_configure_event_cb:w:%d h:%d\n", area->w, area->h);
+	/*
+	   g_print ("glarea_configure_event_cb:w:%d h:%d\n", area->w, area->h);
+	 */
 
 	return FALSE;
 }
@@ -771,61 +708,31 @@ glarea_configure_event_cb (GtkWidget * glarea, GdkEventConfigure * event, gpoint
 static gboolean
 glarea_expose_event_cb (GtkWidget * glarea, GdkEventExpose * event, gpointer data)
 {
-	g_print ("glarea_expose_event_cb\n");
+	/*
+	   g_print ("glarea_expose_event_cb\n");
+	 */
 
 	idle_render = TRUE;
 
 	return FALSE;
 }
 
-static void
-draw_dummy_realize_cb (GtkWidget * widget, gpointer user_data)
-{
-	g_print ("draw_dummy_realize\n");
-
-	glcontext_dummy = gtk_widget_get_gl_context (draw_dummy);
-	gldrawable_dummy = gtk_widget_get_gl_drawable (draw_dummy);
-}
-
-static void
-create_draw_dummy (GtkWidget * draw_main)
-{
-	GdkGLContext *glcontext;
-	GdkGLConfig *glconfig;
-
-	glconfig = gdk_gl_config_new_by_mode (GDK_GL_MODE_RGB | GDK_GL_MODE_DEPTH | GDK_GL_MODE_DOUBLE);
-	if (glconfig == NULL) {
-		g_print ("gl_config_new_by_mode:err\n");
-		exit (1);
-	}
-
-	/* メイン画面のコンテキストを取得 */
-	glcontext = gtk_widget_get_gl_context (draw_main);
-
-	draw_dummy = gtk_drawing_area_new ();
-	g_signal_connect_after (draw_dummy, "realize", G_CALLBACK (draw_dummy_realize_cb), NULL);
-
-	/* メイン画面のコンテキストとディスプレイリストとテクスチャーオブジェクトを共有 */
-	gtk_widget_set_gl_capability (draw_dummy, glconfig, glcontext, TRUE, GDK_GL_RGBA_TYPE);
-
-	g_object_unref (glconfig);
-
-	gtk_box_pack_start (GTK_BOX (hbox_all), draw_dummy, FALSE, FALSE, 0);
-	gtk_widget_show (draw_dummy);
-}
-
 static void
 glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 {
 	DB (g_print ("glarea_realize_cb\n"));
 
-	create_draw_dummy (glarea);
-
 	area_init (glarea);
 
 	glcontext_main = gtk_widget_get_gl_context (glarea);
 	gldrawable_main = gtk_widget_get_gl_drawable (glarea);
 	is_direct = gdk_gl_context_is_direct (glcontext_main);
+	util_print_bool ("direct rendering enable ", is_direct);
+    if(is_direct ==FALSE){
+        g_print("############################################\n");
+        g_print("###     Direct Rendering ""DISABLE""     ###\n");
+        g_print("############################################\n");
+    }
 
 	if (!gdk_gl_drawable_gl_begin (gldrawable_main, glcontext_main)) {
 		g_print ("glarea_realize_cb:gl_begin:false\n");
@@ -880,10 +787,22 @@ glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 			support_vbo = FALSE;
 		}
 
-		/* 圧縮テクスチャーのサポートの有無 */
 		if (gdk_gl_query_gl_extension (compress) == TRUE) {
 			g_print ("%s ------------ supported\n", compress);
 			support_compress = TRUE;
+
+			glGenTextures (1, &t_dummy);
+			glBindTexture (GL_TEXTURE_2D, t_dummy);
+			glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+			glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+			glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+			glTexImage2D (GL_TEXTURE_2D, 0, GL_COMPRESSED_RGB_ARB, 4, 4, 0, GL_RGB, GL_UNSIGNED_BYTE, dummy);
+			glGetTexLevelParameteriv (GL_TEXTURE_2D, 0, GL_TEXTURE_COMPRESSED_IMAGE_SIZE, &bytes);
+			/* こんな所で得た texture_format を全てのテクスチャーのフォーマットだとしてるが、いいのか？ */
+			glGetTexLevelParameteriv (GL_TEXTURE_2D, 0, GL_TEXTURE_INTERNAL_FORMAT, &texture_format);
+
+			g_print ("dummy:bytes:%d format:%x\n", bytes, texture_format);
+
 		} else {
 			g_print ("%s ------------ not supported\n", compress);
 			support_compress = FALSE;
@@ -894,22 +813,10 @@ glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 		if (max_texture_size >= 2048) {
 			max_texture_size = 2048;
 		} else {
-			g_print ("??? max_texture_size:%d\n", max_texture_size);
+			g_print ("oops! max_texture_size:%d < 2048\n", max_texture_size);
 			exit (1);
 		}
 
-		glGenTextures (1, &t_dummy);
-		glBindTexture (GL_TEXTURE_2D, t_dummy);
-		glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-		glTexImage2D (GL_TEXTURE_2D, 0, GL_COMPRESSED_RGB_ARB, 4, 4, 0, GL_RGB, GL_UNSIGNED_BYTE, dummy);
-		glGetTexLevelParameteriv (GL_TEXTURE_2D, 0, GL_TEXTURE_COMPRESSED_IMAGE_SIZE, &bytes);
-		/* こんな所で得た texture_format を全てのテクスチャーのフォーマットだとしてるが、いいのか？ */
-		glGetTexLevelParameteriv (GL_TEXTURE_2D, 0, GL_TEXTURE_INTERNAL_FORMAT, &texture_format);
-
-		g_print ("dummy:bytes:%d format:%x\n", bytes, texture_format);
-
 		info_init ();
 	}
 	gdk_gl_drawable_gl_end (gldrawable_main);
@@ -922,12 +829,8 @@ glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 	g_signal_connect (area->glarea, "button_press_event", G_CALLBACK (glarea_mouse_press_cb), NULL);
 
 	if (saveimage_check_glx (glarea) == FALSE) {
-        /*
 		window_menu_saveimage_sensitive (FALSE);
-        */
 	}
-
-	g_print ("glarea_realize_cb:end\n");
 }
 
 /*********************************/
@@ -959,7 +862,10 @@ glarea_create (void)
 	glarea = gtk_drawing_area_new ();
 	gtk_widget_set_events (glarea, GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK |
 						   GDK_BUTTON_PRESS_MASK | GDK_EXPOSURE_MASK);
-	gtk_widget_set_gl_capability (glarea, glconfig, NULL, TRUE, GDK_GL_RGBA_TYPE);
+	if (gtk_widget_set_gl_capability (glarea, glconfig, NULL, TRUE, GDK_GL_RGBA_TYPE) == FALSE) {
+		g_print ("glarea_create:gtk_widget_set_gl_capability:fail\n");
+		exit (1);
+	}
 	g_signal_connect (glarea, "realize", G_CALLBACK (glarea_realize_cb), NULL);
 
 	g_object_unref (glconfig);
