@@ -28,8 +28,8 @@ void glarea_force_render (void);
 void glarea_force_update_and_render (void);
 void glarea_get_size (gint * w, gint * h);
 
-gboolean glarea_dummy_gl_begin (void);
-void glarea_dummy_gl_end (void);
+gboolean glarea_gl_begin (void);
+void glarea_gl_end (void);
 
 gint glarea_get_texture_format (void);
 gboolean glarea_is_support_compress (void);
@@ -38,8 +38,6 @@ gboolean glarea_is_direct (void);
 
 void glarea_tilt_lock (gboolean bool);
 
-void glarea_util_texture_free (guint n);
-
 gint glarea_get_max_texture_size (void);
 
 void glarea_process_start (void);
