@@ -388,7 +388,8 @@ lzh_extract (const gchar * lzh)
 	 */
 	current_dir = g_get_current_dir ();
 	chdir (mmap_dir_gsi_vn);
-	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL, NULL, &err);
+	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, NULL, NULL, NULL, NULL, NULL,
+				  &err);
 	if (err != NULL) {
 		g_print ("spawn error::lzh_extract:%s:\n", err->message);
 	}
@@ -418,14 +419,14 @@ get_lzh (City * city, const gchar * slm, const gchar * sal, const gchar * slp, c
 		/* キャッシュに何もなかったのでダウンロード後に展開する */
 		const gchar *uri_l = "http://sdf.gsi.go.jp/data25k/";
 		gchar *uri;
-		gchar *data;
+		void *data;
 		gint bytes;
 
 		uri = g_strconcat (uri_l, city->path, ".lzh", NULL);	/* aichi/11111 */
 
 		data = net_download (uri, &bytes);
 		if (data == NULL) {
-			g_print ("error: net_download_sync return NULL:%s\n", city->path);
+			g_print ("error: net_download return NULL:%s\n", city->path);
 			exit (1);
 		}
 
