@@ -72,11 +72,14 @@ Hani hani[] = {
 	{1, "北海道"},
 	{2, "青森"}, {3, "岩手"}, {4, "宮城"}, {5, "秋田"}, {6, "山形"}, {7, "福島"},
 	{8, "茨城"}, {9, "栃木"}, {10, "群馬"}, {11, "埼玉"}, {12, "千葉"}, {13, "東京"}, {14, "神奈川"},
-	{15, "新潟"}, {16, "富山"}, {17, "石川"}, {18, "福井"}, {19, "山梨"}, {20, "長野"}, {21, "岐阜"}, {22, "静岡"}, {23, "愛知"},
+	{15, "新潟"}, {16, "富山"}, {17, "石川"}, {18, "福井"}, {19, "山梨"}, {20, "長野"}, {21, "岐阜"}, {22,
+																													 "静岡"},
+		{23, "愛知"},
 	{24, "三重"}, {25, "滋賀"}, {26, "京都"}, {27, "大阪"}, {28, "兵庫"}, {29, "奈良"}, {30, "和歌山"},
 	{31, "鳥取"}, {32, "島根"}, {33, "岡山"}, {34, "広島"}, {35, "山口"},
 	{36, "徳島"}, {37, "香川"}, {38, "愛媛"}, {39, "高知"},
-	{40, "福岡"}, {41, "佐賀"}, {42, "長崎"}, {43, "熊本"}, {44, "大分"}, {45, "宮崎"}, {46, "鹿児島"}, {47, "沖縄"}
+	{40, "福岡"}, {41, "佐賀"}, {42, "長崎"}, {43, "熊本"}, {44, "大分"}, {45, "宮崎"}, {46, "鹿児島"},
+		{47, "沖縄"}
 };
 
 typedef struct {
@@ -242,80 +245,80 @@ make_list_data_sub (GtkTreeIter * iter, const gchar * text, gdouble x, gdouble y
 }
 
 static void
-line_analysis_sub(const gchar *line, GtkTreeIter *iter)
+line_analysis_sub (const gchar * line, GtkTreeIter * iter)
 {
-    gchar *start;
-    gchar *end;
-    gint n;
-    gchar *tmp;
+	gchar *start;
+	gchar *end;
+	gint n;
+	gchar *tmp;
 
-    gchar *mark;
-    gdouble lon, lat;
-    gchar *text0, *text1, *text2;
-    gchar *all;
+	gchar *mark;
+	gdouble lon, lat;
+	gchar *text0, *text1, *text2;
+	gchar *all;
 
-    start = (gchar *)line;
-    end = g_strstr_len(line, 20, "&nbsp;<a");
-    n = end - start;
-    mark = g_strndup(start, n);
+	start = (gchar *) line;
+	end = g_strstr_len (line, 20, "&nbsp;<a");
+	n = end - start;
+	mark = g_strndup (start, n);
 
-    g_print("mark:%s\n", mark);
+	g_print ("mark:%s\n", mark);
 
-    start = g_strrstr(line, "latitude=");
+	start = g_strrstr (line, "latitude=");
 	start += strlen ("latitude=");
-    end = g_strrstr(line, "&longitude=");
-    n = end - start;
-    tmp = g_strndup(start, n);
+	end = g_strrstr (line, "&longitude=");
+	n = end - start;
+	tmp = g_strndup (start, n);
 	sscanf (tmp, "%le", &lat);
-    g_free(tmp);
+	g_free (tmp);
 
-    start = g_strrstr(line, "longitude=");
+	start = g_strrstr (line, "longitude=");
 	start += strlen ("longitude=");
-    end = g_strrstr(line, "\" target=");
-    n = end - start;
-    tmp = g_strndup(start, n);
+	end = g_strrstr (line, "\" target=");
+	n = end - start;
+	tmp = g_strndup (start, n);
 	sscanf (tmp, "%le", &lon);
-    g_free(tmp);
+	g_free (tmp);
 
-    g_print("lon:%e lat:%e\n", lon, lat);
+	g_print ("lon:%e lat:%e\n", lon, lat);
 
-    start = g_strrstr(line, "_top\">");
+	start = g_strrstr (line, "_top\">");
 	start += strlen ("_top\">");
-    end = g_strrstr(line, "</a>");
-    n = end - start;
-    text0 = g_strndup(start, n);
+	end = g_strrstr (line, "</a>");
+	n = end - start;
+	text0 = g_strndup (start, n);
 
-    g_print("text0:%s\n", text0);
+	g_print ("text0:%s\n", text0);
 
-    start = g_strrstr(line, "（");
+	start = g_strrstr (line, "（");
 	start += strlen ("（");
-    end = g_strrstr(line, "）");
-    n = end - start;
-    /* 公共施設名には読みがないので括弧が見付からない */
-    if( start != NULL && end != NULL){
-        text1 = g_strndup(start, n);
-    }else{
-        text1 = g_strdup("");
-    }
+	end = g_strrstr (line, "）");
+	n = end - start;
+	/* 公共施設名には読みがないので括弧が見付からない */
+	if (start != NULL && end != NULL) {
+		text1 = g_strndup (start, n);
+	} else {
+		text1 = g_strdup ("");
+	}
 
-    g_print("text1:%s\n", text1);
+	g_print ("text1:%s\n", text1);
 
-    start = g_strrstr(line, "/&nbsp;&nbsp;");
+	start = g_strrstr (line, "/&nbsp;&nbsp;");
 	start += strlen ("/&nbsp;&nbsp;");
-    text2 = g_strdup(start);
+	text2 = g_strdup (start);
 
-    g_print("text2:%s\n", text2);
+	g_print ("text2:%s\n", text2);
 
-    all = g_strconcat(mark, " ", text0, " ", text1, " ", text2, NULL);
+	all = g_strconcat (mark, " ", text0, " ", text1, " ", text2, NULL);
 
-    make_list_data_sub (iter, all,  lon, lat);
+	make_list_data_sub (iter, all, lon, lat);
 
-    g_print("text:%s: lon:%e lat:%e\n", all, lon, lat);
+	g_print ("text:%s: lon:%e lat:%e\n", all, lon, lat);
 
-    g_free(mark);
-    g_free(text0);
-    g_free(text1);
-    g_free(text2);
+	g_free (mark);
+	g_free (text0);
+	g_free (text1);
+	g_free (text2);
 }
 
 static void
@@ -325,17 +328,17 @@ line_analysis (const gchar * line)
 	gchar *end;
 	gint n;						/* start と end に囲まれた文字数 */
 	gchar *tmp;
-    gchar **token;
-    gchar **p;
-    GtkTreeIter iter;
+	gchar **token;
+	gchar **p;
+	GtkTreeIter iter;
 
 	DEBUG (g_print ("line_analysis:%s\n", line));
 
 
-    /* 結果の必要部分の切り出し */
+	/* 結果の必要部分の切り出し */
 	start = g_strrstr (line, "left;\">");
 	start += strlen ("left;\">");
-	end = g_strrstr (line, "<br></p>"); /* 最後の <br> を入れるのは、空要素が最後に付くのを防ぐため */
+	end = g_strrstr (line, "<br></p>");	/* 最後の <br> を入れるのは、空要素が最後に付くのを防ぐため */
 	n = end - start;
 
 	tmp = g_strndup (start, n);
@@ -345,10 +348,10 @@ line_analysis (const gchar * line)
 
 	g_free (tmp);
 
-    for(p = token; *p != NULL; ++p){
-        g_print("##%s##\n", *p);
-        line_analysis_sub(*p, &iter);
-    }
+	for (p = token; *p != NULL; ++p) {
+		g_print ("##%s##\n", *p);
+		line_analysis_sub (*p, &iter);
+	}
 
 	g_strfreev (token);
 
@@ -356,24 +359,24 @@ line_analysis (const gchar * line)
 }
 
 static int
-get_n_result(const gchar *line)
+get_n_result (const gchar * line)
 {
-    gchar *start;
-    gchar *end;
-    gint len;
-    gchar *tmp;
-    gint n;
+	gchar *start;
+	gchar *end;
+	gint len;
+	gchar *tmp;
+	gint n;
 
 	start = g_strrstr (line, "(");
-    start += strlen("(");
+	start += strlen ("(");
 	end = g_strrstr (line, "件");
-    len = end - start;
+	len = end - start;
 
-    tmp = g_strndup(start, len);
+	tmp = g_strndup (start, len);
 	sscanf (tmp, "%d", &n);
-    g_free(tmp);
+	g_free (tmp);
 
-    return n;
+	return n;
 }
 
 /* 引数の html は utf8 */
@@ -382,11 +385,11 @@ html_analysis (const gchar * html)
 {
 	gchar **token = NULL;
 	gchar **p;
-    gchar *line0 = NULL;   /* 検索結果の数が入った行 */
-    gchar *line1 = NULL;   /* ◯〜◯件の文字と[次へ]と[前へ]のリンクが入った行 */
-    gchar *line2 = NULL;   /* 検索結果本体の行 */
-    gboolean prev = FALSE;
-    gboolean next = FALSE;
+	gchar *line0 = NULL;		/* 検索結果の数が入った行 */
+	gchar *line1 = NULL;		/* ◯〜◯件の文字と[次へ]と[前へ]のリンクが入った行 */
+	gchar *line2 = NULL;		/* 検索結果本体の行 */
+	gboolean prev = FALSE;
+	gboolean next = FALSE;
 
 	if (html == NULL) {
 		return;
@@ -394,107 +397,107 @@ html_analysis (const gchar * html)
 
 	token = g_strsplit (html, "\n", 0);
 
-	for(p = token; *p != NULL; ++p) {
+	for (p = token; *p != NULL; ++p) {
 		if (g_strrstr (*p, "large") != NULL) {
-            line0 = *p;
-            ++p;
-            line1 = *p;
-            ++p;
-            line2 = *p;
+			line0 = *p;
+			++p;
+			line1 = *p;
+			++p;
+			line2 = *p;
 
-            break;
+			break;
 		}
 	}
 
-    n_result = get_n_result(line0);
-    {
-        gchar *label;
-        gint s;
-        gint e;
+	n_result = get_n_result (line0);
+	{
+		gchar *label;
+		gint s;
+		gint e;
 
-        if( n_result == 0){
-            s = 0;
-        }else{
-            s = start + 1;
-        }
+		if (n_result == 0) {
+			s = 0;
+		} else {
+			s = start + 1;
+		}
 
-        if( n_result < start + 50){
-            e = n_result;
-        }else{
-            e = start + 50;
-        }
+		if (n_result < start + 50) {
+			e = n_result;
+		} else {
+			e = start + 50;
+		}
 
-        label = g_strdup_printf("検索結果 %d 件中 ( %d - %d )", n_result, s,  e);
-        gtk_label_set_text(GTK_LABEL(label_result), label);
+		label = g_strdup_printf ("検索結果 %d 件中 ( %d - %d )", n_result, s, e);
+		gtk_label_set_text (GTK_LABEL (label_result), label);
 
-        g_free(label);
-    }
-    /*
-    g_print("n:%d\n", n_result);
-    */
-    g_print("n:%d\n", n_result);
+		g_free (label);
+	}
+	/*
+	   g_print("n:%d\n", n_result);
+	 */
+	g_print ("n:%d\n", n_result);
 
-    if(g_strrstr(line1, "前へ") == NULL){
-        prev = FALSE;
-    }else{
-        prev = TRUE;
-    }
+	if (g_strrstr (line1, "前へ") == NULL) {
+		prev = FALSE;
+	} else {
+		prev = TRUE;
+	}
 
-    if(g_strrstr(line1, "次へ") == NULL){
-        next = FALSE;
-    }else{
-        next = TRUE;
-    }
-    gtk_widget_set_sensitive(b_prev, prev);
-    gtk_widget_set_sensitive(b_next, next);
+	if (g_strrstr (line1, "次へ") == NULL) {
+		next = FALSE;
+	} else {
+		next = TRUE;
+	}
+	gtk_widget_set_sensitive (b_prev, prev);
+	gtk_widget_set_sensitive (b_next, next);
 
-    /*
-    util_print_bool("prev:", prev);
-    util_print_bool("next:", next);
-    */
-    util_print_bool("prev:", prev);
-    util_print_bool("next:", next);
+	/*
+	   util_print_bool("prev:", prev);
+	   util_print_bool("next:", next);
+	 */
+	util_print_bool ("prev:", prev);
+	util_print_bool ("next:", next);
 
-    if(n_result != 0){
-	    line_analysis (line2);
-    }
+	if (n_result != 0) {
+		line_analysis (line2);
+	}
 
-    g_print("line0:%s\n", line0);
-    g_print("line1:%s\n", line1);
-    g_print("line2:%s\n", line2);
+	g_print ("line0:%s\n", line0);
+	g_print ("line1:%s\n", line1);
+	g_print ("line2:%s\n", line2);
 
 	g_strfreev (token);
 }
 
 
 static gchar
-check_button_get_t_or_f(GtkWidget *button)
+check_button_get_t_or_f (GtkWidget * button)
 {
-    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)) == TRUE){
-            return 't';
-    }else{
-            return 'f';
-    }
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE) {
+		return 't';
+	} else {
+		return 'f';
+	}
 }
 
 static gchar *
-get_uri(void)
+get_uri (void)
 {
 	gchar *uri;
 	const gchar *searchwords_utf;
 	gchar *searchwords;
-    gchar chuki;
-    gchar koukyou;
+	gchar chuki;
+	gchar koukyou;
 	gint pref;					/* 検索範囲 */
 
 	searchwords_utf = gtk_entry_get_text (GTK_ENTRY (entry_searchwords));
 	searchwords = utf_to_url (searchwords_utf);
 	pref = get_hani ();
-    chuki = check_button_get_t_or_f(cb_chuki);
-    koukyou = check_button_get_t_or_f(cb_koukyou);
+	chuki = check_button_get_t_or_f (cb_chuki);
+	koukyou = check_button_get_t_or_f (cb_koukyou);
 
 	uri = g_strdup_printf ("http://watchizu.gsi.go.jp/search.aspx?searchwords=%s&start=%d&pref=%d&chuki=%c&koukyou=%c",
-                                 searchwords, start, pref, chuki, koukyou);
+						   searchwords, start, pref, chuki, koukyou);
 	DEBUG (g_print (":%s:%s:\n", searchwords, uri));
 
 	g_free (searchwords);
@@ -505,45 +508,43 @@ get_uri(void)
 static void
 search_start (void)
 {
-	gchar *uri;
-	gchar *html_sjis;
-	gchar *html_utf;
-    gint size;
+	gchar *uri = NULL;
+	gchar *html_sjis = NULL;
+	gchar *html_utf = NULL;
+	gint size;
 	GtkTreeView *treeview = GTK_TREE_VIEW (list_widget);
 	GtkTreeModel *model;
 
-    /* 結果のクリアー */
+	/* 結果のクリアー */
 	model = gtk_tree_view_get_model (treeview);
 	gtk_list_store_clear (GTK_LIST_STORE (model));
 
-    n_result = 0;
+	n_result = 0;
 
 	uri = get_uri ();
 	html_sjis = net_download (uri, &size);
 
-	g_print ("size:%d byte uri:%s\n", size, uri);
-
-	g_free (uri);
 
 	if (html_sjis == NULL) {
-		return;
+		g_print ("search_start:net_download return NULL:size %d: %s\n", size, uri);
+	} else {
+		html_utf = util_to_utf (html_sjis, SJIS);
+
+		DEBUG (g_print ("html%s\n", html_utf));
+
+		html_analysis (html_utf);
 	}
 
-	html_utf = util_to_utf (html_sjis, SJIS);
-	free (html_sjis);
-
-	DEBUG (g_print ("html%s\n", html_utf));
-	g_print ("html%s\n", html_utf);
-
-	html_analysis (html_utf);
+	g_free (uri);
+	g_free (html_sjis);
 	g_free (html_utf);
 }
 
 static void
 search_button_clicked_cb (GtkButton * button, gpointer user_data)
 {
-    start = 0;
-    n_result = 0;
+	start = 0;
+	n_result = 0;
 	search_start ();
 }
 
@@ -559,10 +560,10 @@ create_taisyou (void)
 	GtkWidget *vbox;
 	GtkWidget *frame;
 
-    cb_chuki = gtk_check_button_new_with_label ("地名等注記");
-    cb_koukyou = gtk_check_button_new_with_label ("公共施設等");
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cb_chuki), TRUE);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cb_koukyou), TRUE);
+	cb_chuki = gtk_check_button_new_with_label ("地名等注記");
+	cb_koukyou = gtk_check_button_new_with_label ("公共施設等");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cb_chuki), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cb_koukyou), TRUE);
 
 	vbox = gtk_vbox_new (FALSE, 1);
 	gtk_box_pack_start (GTK_BOX (vbox), cb_chuki, FALSE, FALSE, 0);
@@ -646,8 +647,8 @@ create_hani (void)
 static void
 entry_activate_cb (GtkEntry * entry, gpointer user_data)
 {
-    start = 0;
-    n_result = 0;
+	start = 0;
+	n_result = 0;
 	search_start ();
 }
 
@@ -672,24 +673,24 @@ create_moji (void)
 
 
 static void
-prev_clicked_cb(GtkButton *button, gpointer   user_data)
+prev_clicked_cb (GtkButton * button, gpointer user_data)
 {
-    start -= 50;
+	start -= 50;
 	search_start ();
 }
 
 static void
-next_clicked_cb(GtkButton *button, gpointer   user_data)
+next_clicked_cb (GtkButton * button, gpointer user_data)
 {
-    start += 50;
+	start += 50;
 	search_start ();
 }
 
 static GtkWidget *
 create_kekka (void)
 {
-    GtkWidget *hbox;
-    GtkWidget *vbox;
+	GtkWidget *hbox;
+	GtkWidget *vbox;
 	GtkWidget *frame;
 	GtkWidget *scroll;
 	GtkListStore *list_store;
@@ -701,7 +702,7 @@ create_kekka (void)
 	g_signal_connect (list_widget, "row-activated", G_CALLBACK (list_row_activated_cb), NULL);
 	g_object_unref (G_OBJECT (list_store));
 
-    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(list_widget), FALSE);
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (list_widget), FALSE);
 
 	column = gtk_tree_view_column_new ();
 
@@ -719,11 +720,11 @@ create_kekka (void)
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
 	gtk_container_add (GTK_CONTAINER (frame), scroll);
 
-    label_result = gtk_label_new("検索結果");
-    b_prev = gtk_button_new_with_label("前へ");
-    b_next = gtk_button_new_with_label("次へ");
-    gtk_widget_set_sensitive(b_prev, FALSE);
-    gtk_widget_set_sensitive(b_next, FALSE);
+	label_result = gtk_label_new ("検索結果");
+	b_prev = gtk_button_new_with_label ("前へ");
+	b_next = gtk_button_new_with_label ("次へ");
+	gtk_widget_set_sensitive (b_prev, FALSE);
+	gtk_widget_set_sensitive (b_next, FALSE);
 	g_signal_connect (b_prev, "clicked", G_CALLBACK (prev_clicked_cb), NULL);
 	g_signal_connect (b_next, "clicked", G_CALLBACK (next_clicked_cb), NULL);
 
@@ -745,7 +746,7 @@ dialog_response_cb (GtkDialog * dialog, gint arg1, gpointer user_data)
 	GtkTreeView *treeview = GTK_TREE_VIEW (list_widget);
 	GtkTreeModel *model;
 	GtkListStore *liststore;
-    GtkAction *action = GTK_ACTION(user_data);
+	GtkAction *action = GTK_ACTION (user_data);
 
 	g_print ("dialog_response_cb\n");
 
@@ -759,11 +760,11 @@ dialog_response_cb (GtkDialog * dialog, gint arg1, gpointer user_data)
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 
-    gtk_action_set_sensitive(action, TRUE);
+	gtk_action_set_sensitive (action, TRUE);
 }
 
 void
-mmapsearch_dialog_create (GtkAction *action)
+mmapsearch_dialog_create (GtkAction * action)
 {
 	GtkWidget *taisyou;
 	GtkWidget *hani;
@@ -777,15 +778,15 @@ mmapsearch_dialog_create (GtkAction *action)
 	GtkWidget *button2;
 	GtkWidget *vbox_button;
 
-    gtk_action_set_sensitive(action, FALSE);
+	gtk_action_set_sensitive (action, FALSE);
 
 	hani = create_hani ();
 	taisyou = create_taisyou ();
 	moji = create_moji ();
 	kekka = create_kekka ();
 
-	button1 = gtk_button_new_with_label(_("Search"));
-	button2 = gtk_button_new_with_label(_("Clear"));
+	button1 = gtk_button_new_with_label (_("Search"));
+	button2 = gtk_button_new_with_label (_("Clear"));
 	g_signal_connect (button1, "clicked", G_CALLBACK (search_button_clicked_cb), NULL);
 	g_signal_connect (button2, "clicked", G_CALLBACK (clear_button_clicked_cb), NULL);
 	vbox_button = gtk_vbox_new (FALSE, 0);
