@@ -120,8 +120,9 @@ ww_quadchild_get_type (void)
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT, "WwQuadchild", &info, 0);
-
+        /*
 		g_print ("ww_quadchild_get_type\n");
+        */
 	}
 
 	return type;
@@ -277,15 +278,17 @@ ww_quadchild_new (void)
 /********************************************************************/
 
 static void
-ww_quadchild_texture_process (GObject * obj)
+quadchild_change_texture_cb (WwTexture * texture, gpointer data)
 {
-	WwQuadchild *child = WW_QUADCHILD (obj);
-	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
-	WwTexture *texture;
+	WwQuadchildPrivate *priv;
+	WwQuadchild *child;
 
-	g_print ("ww_quadchild_texture_process:L:%d x:%d y:%d\n", priv->level, priv->x, priv->y);
+	g_return_if_fail (WW_IS_TEXTURE (texture));
+	g_return_if_fail (WW_IS_QUADCHILD (data));
 
-	texture = ww_texture_new_data (priv->data, priv->size, priv->path_jpg, priv->path_dds);
+	child = WW_QUADCHILD (data);
+
+	priv = WW_QUADCHILD_GET_PRIVATE (child);
 
 	g_mutex_lock (priv->mutex_texture_and_mesh);
 	{
@@ -298,6 +301,33 @@ ww_quadchild_texture_process (GObject * obj)
 	}
 	g_mutex_unlock (priv->mutex_texture_and_mesh);
 
+	g_object_unref (child);
+
+	glarea_force_update_and_render ();
+}
+
+static void
+ww_quadchild_texture_process (GObject * obj)
+{
+	WwQuadchild *child = WW_QUADCHILD (obj);
+	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
+	WwTexture *texture;
+
+	/*
+	   g_print ("ww_quadchild_texture_process:L:%d x:%d y:%d\n", priv->level, priv->x, priv->y);
+	 */
+
+	if (priv->data == NULL) {
+		/* データがないといつまでたっても initialized は FALSE */
+		return;
+	}
+
+	texture = ww_texture_new_data (priv->data, priv->size, priv->path_jpg, priv->path_dds);
+
+	g_object_ref (obj);
+	g_signal_connect (G_OBJECT (texture), "initialized", G_CALLBACK (quadchild_change_texture_cb), obj);
+	mmap_idle_add_single (ww_texture_gen, G_OBJECT (texture));
+
 	g_free (priv->data);
 	priv->data = NULL;
 
@@ -320,7 +350,7 @@ ww_quadchild_texture_download (GObject * obj)
 		return;
 	}
 
-	priv->data = net_download (priv->uri, &size);
+	priv->data = mmapthread_download_get (priv->uri, &size);
 	priv->size = size;
 
 	mmapthread_add_power (ww_quadchild_texture_process, obj);
@@ -348,32 +378,20 @@ create_texture_sub (GObject * obj)
 
 	if (filetest (priv->path_dds) == TRUE) {
 		texture = ww_texture_new_dds (priv->path_dds, 512, 512);
-		g_mutex_lock (priv->mutex_texture_and_mesh);
-		{
-			if (priv->texture != NULL) {
-				g_object_unref (priv->texture);
-			}
-			priv->texture = texture;
-			priv->texture_initialized = TRUE;
-			ww_mesh_change_type (priv->mesh, WW_MESH_TYPE_NORMAL);
-		}
-		g_mutex_unlock (priv->mutex_texture_and_mesh);
+
+		g_object_ref (obj);
+		g_signal_connect (G_OBJECT (texture), "initialized", G_CALLBACK (quadchild_change_texture_cb), obj);
+		mmap_idle_add_single (ww_texture_gen, G_OBJECT (texture));
 
 	} else if (filetest (priv->path_jpg) == TRUE) {
 		texture = ww_texture_new_jpg (priv->path_jpg, priv->path_dds);
-		g_mutex_lock (priv->mutex_texture_and_mesh);
-		{
-			if (priv->texture != NULL) {
-				g_object_unref (priv->texture);
-			}
-			priv->texture = texture;
-			priv->texture_initialized = TRUE;
-			ww_mesh_change_type (priv->mesh, WW_MESH_TYPE_NORMAL);
-		}
-		g_mutex_unlock (priv->mutex_texture_and_mesh);
+
+		g_object_ref (obj);
+		g_signal_connect (G_OBJECT (texture), "initialized", G_CALLBACK (quadchild_change_texture_cb), obj);
+		mmap_idle_add_single (ww_texture_gen, G_OBJECT (texture));
 
 	} else {
-		mmapthread_add_download (ww_quadchild_texture_download, (GObject *) child);
+		mmapthread_add_download2 (priv->uri, ww_quadchild_texture_download, (GObject *) child);
 	}
 }
 
@@ -391,6 +409,10 @@ create_mesh_from_data (GObject * obj)
 	/*
 	   g_print("create_mesh_from_data\n");
 	 */
+	if (priv->is_detached == TRUE) {
+		g_print ("mesh_download:L:%d x:%d y:%d  is_detached\n", priv->level, priv->x, priv->y);
+		return;
+	}
 
 	x0 = (priv->x + 0) * priv->tile_deg - 180.0;
 	x1 = (priv->x + 1) * priv->tile_deg - 180.0;
@@ -402,9 +424,22 @@ create_mesh_from_data (GObject * obj)
 
 	g_mutex_lock (priv->mutex_texture_and_mesh);
 	{
-		g_object_unref (priv->mesh);
-		priv->mesh = mesh;
-		priv->mesh_initialized = TRUE;
+		WwMeshType old_type;
+
+		if (priv->mesh != NULL) {
+			/* update() は mesh の完了を待ってくれないので、すでに unref されている可能性がある。 */
+
+			old_type = ww_mesh_get_mesh_type (priv->mesh);
+			g_object_unref (priv->mesh);
+			priv->mesh = mesh;
+			priv->mesh_initialized = TRUE;
+			/* これをしないと、texture より mesh が先にできた時に、mesh だけ先行して NORMAL になり同じ texture が
+			 * ４枚表示されたりする。 */
+			ww_mesh_change_type (priv->mesh, old_type);
+		} else {
+			;
+		}
+
 	}
 	g_mutex_unlock (priv->mutex_texture_and_mesh);
 }
@@ -419,6 +454,10 @@ mesh_download (GObject * obj)
 	/*
 	   g_print("mesh_download\n");
 	 */
+	if (priv->is_detached == TRUE) {
+		g_print ("mesh_download:L:%d x:%d y:%d  is_detached\n", priv->level, priv->x, priv->y);
+		return;
+	}
 
 	x0 = (priv->x + 0) * priv->tile_deg - 180.0;
 	x1 = (priv->x + 1) * priv->tile_deg - 180.0;
@@ -483,6 +522,8 @@ create_mesh_sub (GObject * obj)
 	y1 = (y + 1) * tile_deg - 90.0;
 
 	if (terrain_mapped == TRUE) {
+		const gchar *url;
+
 		if (priv->mesh == NULL) {
 			/* 新規作成なら */
 			mesh = ww_mesh_new_simple (x1, x0, y1, y0, SPLIT, SPLIT, above_surface, terrain_mapped);
@@ -502,7 +543,9 @@ create_mesh_sub (GObject * obj)
 			g_mutex_unlock (priv->mutex_texture_and_mesh);
 		}
 
-		mmapthread_add_download (mesh_download, obj);
+		url = ww_terrainaccessor_get_server_url (priv->ta);
+
+		mmapthread_add_download2 (url, mesh_download, obj);
 	} else {
 		if (priv->mesh == NULL) {
 			/* 新規作成なら */
@@ -538,7 +581,9 @@ ww_quadchild_new_child (WwQuadtile * tile, gint x, gint y, gint level, gdouble t
 	const gchar *world_name = mmap_get_world_name ();
 	const gchar *ext = ww_quadtile_get_image_file_extension (tile);
 
-	g_print ("ww_quadchild_new_child:x:%d y:%d level:%d\n", x, y, level);
+	/*
+	   g_print ("ww_quadchild_new_child:x:%d y:%d level:%d\n", x, y, level);
+	 */
 
 	child = ww_quadchild_new ();
 	priv = WW_QUADCHILD_GET_PRIVATE (child);
@@ -597,14 +642,15 @@ ww_quadchild_new_root (WwQuadtile * tile, gint x, gint y, gint level, gdouble ti
 	priv->path_jpg =
 		g_strdup_printf ("%s%s/%s%d/%04d/%04d_%04d.%s", mmap_dir_cache, world_name, path, level, y, y, x, ext);
 	priv->uri = g_strdup_printf ("%s?T=%s&L=%d&X=%d&Y=%d", server_url, data_set_name, level, x, y);
-	g_print ("ww_quadchild_new_root:path_dds:%s\n", priv->path_dds);
+	/*
+	   g_print ("ww_quadchild_new_root:path_dds:%s\n", priv->path_dds);
+	 */
 
 	priv->ta = mmap_get_terrainaccessor (x * tile_deg, y * tile_deg, (x + 1) * tile_deg, (y + 1) * tile_deg);
 
 	mmapthread_add_power (create_texture_sub, (GObject *) child);
 	mmapthread_add_power (create_mesh_sub, (GObject *) child);
 
-
 	g_free (path);
 
 	return child;
@@ -706,6 +752,9 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
 	gboolean in_view;
 
+	/*
+	   if ((priv->texture != NULL && ww_texture_is_initialized(priv->texture) == FALSE) ) {
+	 */
 	if (priv->texture_initialized == FALSE || priv->mesh_initialized == FALSE) {
 		DB_UP (g_print ("ww_quadchild_update:not initialized\n"));
 		/* テクスチャーかメッシュの作成完了待ちなら下のレベルを調べない。 */
@@ -724,6 +773,7 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 
 	DB_UP (g_print ("ww_quadchild_update:x:%d y:%d level:%d   :%d:   ", priv->x, priv->y, priv->level, level));
 
+
 	if (priv->state == WW_QUADCHILD_STATE_INIT && in_view == TRUE) {
 		DB_UP (g_print ("INIT  in_view:TRUE\n"));
 
@@ -927,7 +977,6 @@ ww_quadchild_render (WwQuadchild * child)
 		return;
 	}
 
-
 	priv = WW_QUADCHILD_GET_PRIVATE (child);
 
 	DB_RE (g_print ("ww_quadchild_render:L:%d x:%d y:%d\n", priv->level, priv->x, priv->y));
@@ -935,42 +984,16 @@ ww_quadchild_render (WwQuadchild * child)
 	g_mutex_lock (priv->mutex_texture_and_mesh);
 	{
 		gboolean textured;
+		gboolean is_in_progress;
 
 		textured = ww_texture_bind (priv->texture);
 
-		if (priv->state == WW_QUADCHILD_STATE_ORIG) {
-			if (priv->texture_initialized == TRUE) {
-				DB_RE (g_print ("ORIG:initialized\n"));
-				if (textured == TRUE) {
-					ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_TEXTURE, FALSE, priv->level);
-				} else {
-					ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_BOX, FALSE, priv->level);
-				}
-			} else {
-				if (textured == TRUE) {
-					/* TEMP から ORIG への切り替わり時になる */
-					DB_RE (g_print ("ORIG:not initialized:textured\n"));
-					ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_TEXTURE, TRUE, priv->level);
-				} else {
-					DB_RE (g_print ("ORIG:not initialized:not textured\n"));
-					ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_BOX, TRUE, priv->level);
-				}
-			}
-		} else if (priv->state == WW_QUADCHILD_STATE_TEMP) {
-			if (priv->texture_initialized == TRUE) {
-				DB_RE (g_print ("TEMP:initialized\n"));
-				if (textured == TRUE) {
-					ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_TEXTURE, FALSE, priv->level);
-				} else {
-					ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_BOX, TRUE, priv->level);
-				}
-			} else {
-				DB_RE (g_print ("TEMP:not initialized\n"));
-				ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_BOX, TRUE, priv->level);
-			}
+		is_in_progress = !(priv->texture_initialized);
+
+		if (textured == TRUE) {
+			ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_TEXTURE, is_in_progress, priv->level);
 		} else {
-			DB_RE (g_print ("INIT\n"));
-			ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_BOX, TRUE, priv->level);
+			ww_mesh_render (priv->mesh, WW_MESH_RENDER_TYPE_BOX, is_in_progress, priv->level);
 		}
 	}
 	g_mutex_unlock (priv->mutex_texture_and_mesh);
@@ -1023,7 +1046,7 @@ ww_quadchild_is_initialized (WwQuadchild * child)
 	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
 	gboolean initialized;
 
-	initialized = priv->texture_initialized && priv->mesh_initialized;
+	initialized = ww_texture_is_initialized (priv->texture) && priv->mesh_initialized;
 
 	return initialized;
 
@@ -1047,8 +1070,9 @@ ww_quadchild_change_vertical_exaggeration (WwQuadchild * child)
 	}
 
 	priv = WW_QUADCHILD_GET_PRIVATE (child);
-
-	g_print ("ww_quadchild_change_vertical_exaggeration:\n");
+	/*
+	   g_print ("ww_quadchild_change_vertical_exaggeration:\n");
+	 */
 
 	ww_mesh_change_vertical_exaggeration (priv->mesh);
 
