@@ -133,8 +133,9 @@ ww_quadtile_get_type (void)
 		type = g_type_register_static (WW_TYPE_OBJECT, "WwQuadtile", &info, 0);
 
 		g_type_add_interface_static (type, WW_TYPE_DATA, &ww_data_info);
-
+        /*
 		g_print ("ww_quadtile_get_type\n");
+        */
 	}
 
 	return type;
@@ -295,7 +296,7 @@ ww_quadtile_new (void)
 
 /********************************************************************/
 
-/* 視点からの距離とレベルゼロの tale_deg から、今どのレベルを表示するべきかを返す。
+/* 視点からの距離とレベルゼロの tile_deg から、今どのレベルを表示するべきかを返す。
  * ####### 物凄いテキトーな計算 ####### 要修正 ###########
  * 表示するべきでないなら -1 を返す。*/
 static gint
@@ -511,14 +512,20 @@ ww_quadtile_update (WwObject * self)
 
 	level = get_level (priv->level_zero_tile_size_degrees, priv->number_levels);
 
-	g_print ("ww_quadtile_update:level(%d):%s\n", level, self->name);
+	/*
+	   g_print ("ww_quadtile_update:level(%d):%s\n", level, self->name);
+	 */
 
 	ww_quadtile_clear_flag (tile);
 
 	/* 表示すべきでない（表示範囲の４分の1以下）なら update しない。update しないと need_flag が
 	 * 落ちたままなので削除される。 */
 	/* update では、必要なら新しい tile を作ったり、必要フラグを落としたりするが、削除まではしない */
-	if (level >= 0) {
+
+	/*
+	   g_print("wwquadtile_updat:%.2f %.2f %.2f %.2f\n", priv->west, priv->south, priv->east, priv->north);
+	 */
+	if (level >= 0 && camera_check_overlap (priv->north, priv->south, priv->west, priv->east) == TRUE) {
 		update_top_level (tile);
 	}
 	g_mutex_lock (priv->mutex_sl_child);
