@@ -44,7 +44,6 @@
 #include "util.h"
 #include "glarea.h"
 #include "mmapthread.h"
-#include "net.h"
 #include "disk.h"
 #include "color.h"
 #include "mmapdata.h"
@@ -127,7 +126,9 @@ ww_smap_get_type (void)
 
 		type = g_type_register_static (G_TYPE_OBJECT, "WwSmap", &info, 0);
 
+        /*
 		g_print ("ww_smap_get_type\n");
+        */
 	}
 
 	return type;
@@ -267,11 +268,34 @@ ww_smap_new (void)
 
 /********************************************************************/
 
+static void
+smap_change_texture_cb (WwTexture * texture, gpointer data)
+{
+	WwSmapPrivate *priv;
+	WwSmap *smap;
+
+	g_return_if_fail (WW_IS_TEXTURE (texture));
+	g_return_if_fail (WW_IS_SMAP (data));
+
+	smap = WW_SMAP (data);
+
+	priv = WW_SMAP_GET_PRIVATE (smap);
+
+	priv->texture = texture;
+	priv->initialized = TRUE;
+
+	g_object_unref (smap);
+
+	glarea_force_update_and_render ();
+}
+
+
 static void
 ww_smap_texture_process (GObject * obj)
 {
 	WwSmap *smap = WW_SMAP (obj);
 	WwSmapPrivate *priv = WW_SMAP_GET_PRIVATE (smap);
+    WwTexture *texture;
 
 	GdkPixbuf *pixbuf;
 	GdkPixbuf *pixbuf_scale;
@@ -285,6 +309,10 @@ ww_smap_texture_process (GObject * obj)
 		return;
 	}
 
+	if (priv->data == NULL) {
+		return;
+	}
+
 	if (priv->name[7] == '0') {
 		left = TRUE;
 	} else {
@@ -295,16 +323,17 @@ ww_smap_texture_process (GObject * obj)
 	pixbuf = util_bin_to_pixbuf (priv->data, priv->size);
 	pixbuf_scale = util_pixbuf_scale_down (pixbuf, left, texture_size);
 
-	priv->texture = ww_texture_new_pixbuf (pixbuf_scale, priv->path_dds);
+	texture = ww_texture_new_pixbuf (pixbuf_scale, priv->path_dds);
+
+	g_object_ref (obj);
+	g_signal_connect (G_OBJECT (texture), "initialized", G_CALLBACK (smap_change_texture_cb), obj);
+	mmap_idle_add_single (ww_texture_gen, G_OBJECT (texture));
 
 	g_object_unref (pixbuf);
 	g_object_unref (pixbuf_scale);
 	g_free (priv->data);
 	priv->data = NULL;
 
-	priv->initialized = TRUE;
-
-	glarea_force_render ();
 }
 
 static void
@@ -320,12 +349,13 @@ ww_smap_texture_download (GObject * obj)
 	}
 
 	g_print ("ww_smap_texture_download:%s:\n", priv->uri);
-	priv->data = net_download (priv->uri, &size);
+	priv->data = mmapthread_download_get (priv->uri, &size);
 	priv->size = size;
 
 	mmapthread_add_power (ww_smap_texture_process, obj);
 }
 
+
 /* 経度方向は、-1 - 225 と 225 - 451 でとり
  * 緯度方向は、+1 - 151 と 151 - 301 でとる */
 WwSmap *
@@ -399,13 +429,21 @@ ww_smap_new_with_name (WwMmap * parent, gint lon_sec, gint lat_sec, const gchar
 	   g_print ("ww_smap_new_with_name:uri:%s\n", priv->uri);
 	 */
 
+	priv->texture = NULL;
+	priv->initialized = FALSE;
+
 	if (filetest (priv->path_dds) == TRUE) {
+		WwTexture *texture;
 		gint max_texture_size = glarea_get_max_texture_size ();
 
-		priv->texture = ww_texture_new_dds (priv->path_dds, max_texture_size, max_texture_size);
-		priv->initialized = TRUE;
+		texture = ww_texture_new_dds (priv->path_dds, max_texture_size, max_texture_size);
+
+		g_object_ref (smap);
+		g_signal_connect (G_OBJECT (texture), "initialized", G_CALLBACK (smap_change_texture_cb), smap);
+		mmap_idle_add_single (ww_texture_gen, G_OBJECT (texture));
 
 	} else if (filetest (priv->path_png) == TRUE) {
+		WwTexture *texture;
 		GdkPixbuf *pixbuf;
 		GdkPixbuf *pixbuf_scale;
 		gint texture_size = glarea_get_max_texture_size ();
@@ -420,17 +458,17 @@ ww_smap_new_with_name (WwMmap * parent, gint lon_sec, gint lat_sec, const gchar
 		pixbuf = disk_load_jpg (priv->path_png);
 		pixbuf_scale = util_pixbuf_scale_down (pixbuf, left, texture_size);
 
-		priv->texture = ww_texture_new_pixbuf (pixbuf_scale, priv->path_dds);
-		priv->initialized = TRUE;
+		texture = ww_texture_new_pixbuf (pixbuf_scale, priv->path_dds);
+
+		g_object_ref (smap);
+		g_signal_connect (G_OBJECT (texture), "initialized", G_CALLBACK (smap_change_texture_cb), smap);
+		mmap_idle_add_single (ww_texture_gen, G_OBJECT (texture));
 
 		g_object_unref (pixbuf);
 		g_object_unref (pixbuf_scale);
 
 	} else {
-		priv->texture = NULL;
-		priv->initialized = FALSE;
-
-		mmapthread_add_download (ww_smap_texture_download, G_OBJECT (smap));
+		mmapthread_add_download2 (priv->uri, ww_smap_texture_download, G_OBJECT (smap));
 	}
 
 	return smap;
@@ -486,7 +524,7 @@ ww_smap_render (WwSmap * smap)
 #endif
 	}
 
-	if (priv->initialized == TRUE) {
+	if (ww_texture_is_initialized (priv->texture) == TRUE) {
 		/* テクスチャーを表示 */
 
 		light_on ();
@@ -598,7 +636,7 @@ ww_smap_color_set (WwSmap * smap)
 {
 	WwSmapPrivate *priv = WW_SMAP_GET_PRIVATE (smap);
 
-    g_print("ww_smap_color_set\n");
+	g_print ("ww_smap_color_set\n");
 
 	mesh_mmap_c_calc (priv->c, priv->v_deg, priv->nv);
 
@@ -822,7 +860,7 @@ ww_smap_vcn_calc (WwSmap * smap)
 		*(priv->v_xyz + k + 2) = z;
 
 		if (alt < 0.0) {
-            /* 海の色は青 */
+			/* 海の色は青 */
 			*(priv->c + k + 0) = 0.6;
 			*(priv->c + k + 1) = 0.7;
 			*(priv->c + k + 2) = 1.0;
@@ -836,8 +874,8 @@ ww_smap_vcn_calc (WwSmap * smap)
 			*(priv->c + k + 2) = (gdouble) b / 0xff;
 		}
 		/*
-		g_print("ww_smap_vcn_calc:alt:%.2f c:%.2f %.2f %.2f\n", alt, *(priv->c + k + 0), *(priv->c + k + 1), *(priv->c + k + 2));
-		*/
+		   g_print("ww_smap_vcn_calc:alt:%.2f c:%.2f %.2f %.2f\n", alt, *(priv->c + k + 0), *(priv->c + k + 1), *(priv->c + k + 2));
+		 */
 	}
 	n_calc (smap);
 
@@ -849,6 +887,8 @@ ww_smap_vcn_calc (WwSmap * smap)
 
 	g_free (path_v);
 	g_free (path_n);
+
+	glarea_force_update_and_render ();
 }
 
 void
