@@ -33,7 +33,7 @@
 #include "mmap.h"
 #include "util.h"
 #include "disk.h"
-#include "net.h"
+#include "mmapthread.h"
 
 /********************************/
 
@@ -463,7 +463,8 @@ extract_7z (const gchar * path_bil_7z, const gchar * odir)
 	/*
 	   g_print ("%s %s %s %s\n", argv[0], argv[1], argv[2], argv[3]);
 	 */
-	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL, NULL, &err);
+	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, NULL, NULL, NULL, NULL, NULL,
+				  &err);
 	if (err != NULL) {
 		g_print ("spawn error:%s:\n", err->message);
 	}
@@ -487,6 +488,9 @@ ww_terrainaccessor_get_alt (WwTerrainaccessor * obj, gdouble lon, gdouble lat)
 		/*
 		   g_print("w:%.2f  e:%.2f  n:%.2f  s:%.2f\n", one->west, one->east, one->north, one->south);
 		 */
+        /*
+		if (lon > one->west && lon <= one->east && lat >= one->south && lat < one->north) {
+        */
 		if (lon >= one->west && lon < one->east && lat >= one->south && lat < one->north) {
 			gint16 *tile = one->tile;
 			gdouble deg = priv->level_zero_tile_size_degrees / pow (2.0, one->level);
@@ -565,8 +569,8 @@ data_download (WwTerrainaccessor * obj, gint level, gint x, gint y)
 
 		uri = g_strdup_printf ("%s?T=%s&L=%d&X=%d&Y=%d", priv->server_url, priv->data_set_name, level, x, y);
 
-		data = net_download (uri, &size);
-		if (data == NULL || size == 0) {
+		data = mmapthread_download_get (uri, &size);
+		if (data == NULL) {
 			g_print ("???get_tile:%s x:%d y:%d\n", priv->name, x, y);
 			g_free (uri);
 			g_free (path_bil);
@@ -745,3 +749,11 @@ ww_terrainaccessor_select (WwTerrainaccessor * obj, gdouble x0, gdouble y0, gdou
 
 	return obj;
 }
+
+const gchar *
+ww_terrainaccessor_get_server_url (WwTerrainaccessor * obj)
+{
+	WwTerrainaccessorPrivate *priv = WW_TERRAINACCESSOR_GET_PRIVATE (obj);
+
+	return priv->server_url;
+}
